@@ -14,4 +14,4 @@ __uri__ = "https://github.com/dfm/aiohttp_spotify"
 __author__ = "Daniel Foreman-Mackey"
 __email__ = "foreman.mackey@gmail.com"
 __license__ = "MIT"
-__description__ = "An interface to the Spotify API that supports aiohttp"
+__description__ = "An async Python interface to the Spotify API using aiohttp"
